package
Version:
v0.0.0-...-d6dc4fc
Opens a new window with list of versions in this module.
Published: Aug 25, 2023
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Prover sends the hash of the data to the verifier.
func Verify(providedHash, expectedHash string) bool
Verifier checks if the provided hash matches the expected hash.
type Data struct {
Content string
}
Data represents the data structure we wish to prove ownership of.
GenerateHash creates a SHA-256 hash of the data's content.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.